@@ -1,6 +1,6 @@
 import sys, os
 from ..core.rule import IRule
-from ..logwriter.writer import term_is_jupyter, create_html, create_color_str
+from ..logwriter.writer import term_is_jupyter, create_html
 from .event_logger import tostrs_func_call
 
 
@@ -12,7 +12,5 @@ def print_method(rule):
     if term_is_jupyter():
         from IPython.display import display, HTML
         display(HTML('<pre>' + create_html(sl, os.getcwd()) + '</pre>'))
-    elif sys.stderr.isatty():
-        sys.stderr.write(create_color_str(sl))
     else:
-        sys.stderr.write(''.join(sl))
+        sys.stdout.write(''.join(sl))
